==> packageinstaller-pkglist-libre_0.1.15.tar.xz: packageinstaller-pkglist-libre/WineHQ.pm <==
<?xml version="1.0"?>
<app>

<category>
Misc
</category>

<name>
Winehq-staging
</name>

<description>
   <am>run Windows applications without a copy of Microsoft Windows</am>
   <ar>run Windows applications without a copy of Microsoft Windows</ar>
   <be>run Windows applications without a copy of Microsoft Windows</be>
   <bg>run Windows applications without a copy of Microsoft Windows</bg>
   <bn>run Windows applications without a copy of Microsoft Windows</bn>
   <ca>Executa aplicacions Windows sense una còpia de MS-Windows</ca>
   <cs>run Windows applications without a copy of Microsoft Windows</cs>
   <da>kør Windows-programmer uden en kopi af Microsoft Windows</da>
   <de>Ausführen von Windows-Anwendungen ohne eine Kopie von Microsoft Windows</de>
   <el>Εκτέλεση εφαρμογών των Windows</el>
   <en>run Windows applications without a copy of Microsoft Windows</en>
   <es_ES>ejecute aplicaciones de Windows sin una copia de Microsoft Windows</es_ES>
   <es>ejecute aplicaciones de Windows sin una copia de Microsoft Windows</es>
   <et>run Windows applications without a copy of Microsoft Windows</et>
   <eu>run Windows applications without a copy of Microsoft Windows</eu>
   <fa>run Windows applications without a copy of Microsoft Windows</fa>
   <fil_PH>run Windows applications without a copy of Microsoft Windows</fil_PH>
   <fi>aja Windows-sovelluksia ilman Microsoft Windowsia</fi>
   <fr_BE>Lancer des applications Windows sans avoir besoin d'installer Windows</fr_BE>
   <fr>Lancer des applications Windows sans avoir besoin d'installer Windows</fr>
   <gl_ES>Executar aplicativos para Windows sen precisar do Microsoft Windows</gl_ES>
   <gu>run Windows applications without a copy of Microsoft Windows</gu>
   <he_IL>run Windows applications without a copy of Microsoft Windows</he_IL>
   <hi>माइक्रोसॉफ्ट विंडोज के बिना ही विंडोज अनुप्रयोग निष्पादित करें</hi>
   <hr>run Windows applications without a copy of Microsoft Windows</hr>
   <hu>run Windows applications without a copy of Microsoft Windows</hu>
   <id>run Windows applications without a copy of Microsoft Windows</id>
   <is>run Windows applications without a copy of Microsoft Windows</is>
   <it>esegue applicazioni Windows senza la presenza del sistema operativo Microsoft Windows</it>
   <ja>Windows のコピーなしで Windows アプリケーションを実行します</ja>
   <kk>run Windows applications without a copy of Microsoft Windows</kk>
   <ko>run Windows applications without a copy of Microsoft Windows</ko>
   <ku>run Windows applications without a copy of Microsoft Windows</ku>
   <lt>run Windows applications without a copy of Microsoft Windows</lt>
   <mk>run Windows applications without a copy of Microsoft Windows</mk>
   <mr>run Windows applications without a copy of Microsoft Windows</mr>
   <nb_NO>run Windows applications without a copy of Microsoft Windows</nb_NO>
   <nb>kjør Windows-programmer uten å ha Microsoft Windows installert</nb>
   <nl_BE>run Windows applications without a copy of Microsoft Windows</nl_BE>
   <nl>Windowstoepassingen uitvoeren zonder een exemplaar van Microsoft Windows</nl>
   <or>run Windows applications without a copy of Microsoft Windows</or>
   <pl>uruchamiaj aplikacje Windows bez kopii systemu Microsoft Windows</pl>
   <pt_BR>Executa aplicativos para Windows sem precisar de uma cópia do Microsoft Windows</pt_BR>
   <pt>Executar aplicações para Windows sem precisar do Microsoft Windows</pt>
   <ro>run Windows applications without a copy of Microsoft Windows</ro>
   <ru>Запуск приложений для Windows в окружении GNU/Linux</ru>
   <sk>run Windows applications without a copy of Microsoft Windows</sk>
   <sl>Poženite Windows aplikacije brez kopije Microsoft Windows</sl>
   <so>run Windows applications without a copy of Microsoft Windows</so>
   <sq>Xhironi aplikacione Windows pa një kopje të Microsoft Windows-it</sq>
   <sr>run Windows applications without a copy of Microsoft Windows</sr>
   <sv>kör Windows applikationer utan Microsoft Windows</sv>
   <th>รันแอปพลิเคชันจาก Windows โดยไม่ต้องใช้ Microsoft Windows</th>
   <tr>Microsoft Windows'un kopyası olmadan Windows uygulamalarını çalıştırma</tr>
   <uk>run Windows applications without a copy of Microsoft Windows</uk>
   <vi>run Windows applications without a copy of Microsoft Windows</vi>
   <zh_CN>run Windows applications without a copy of Microsoft Windows</zh_CN>
   <zh_HK>run Windows applications without a copy of Microsoft Windows</zh_HK>
   <zh_TW>run Windows applications without a copy of Microsoft Windows</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys E1C726CD
echo "deb http://mxrepo.com/mx/repo/ bullseye main non-free">/etc/apt/sources.list.d/pitemp1.list
sleep .1
echo "deb http://mxrepo.com/mx/testrepo/ bullseye test ">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t mx winehq-staging
</install_package_names>


<postinstall>
/usr/share/packageinstaller-pkglist/run_winecfg.sh
rm /etc/apt/sources.list.d/pitemp.list
rm /etc/apt/sources.list.d/pitemp1.list
apt-get update
</postinstall>


<uninstall_package_names>
winehq-staging
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.2.1.tar.xz: packageinstaller-pkglist-libre/WineHQ.pm <==
<?xml version="1.0"?>
<app>

<category>
Misc
</category>

<name>
Winehq-staging
</name>

<description>
   <am>run Windows applications without a copy of Microsoft Windows</am>
   <ar>run Windows applications without a copy of Microsoft Windows</ar>
   <be>run Windows applications without a copy of Microsoft Windows</be>
   <bg>run Windows applications without a copy of Microsoft Windows</bg>
   <bn>run Windows applications without a copy of Microsoft Windows</bn>
   <ca>Executa aplicacions Windows sense una còpia de MS-Windows</ca>
   <cs>run Windows applications without a copy of Microsoft Windows</cs>
   <da>kør Windows-programmer uden en kopi af Microsoft Windows</da>
   <de>Ausführen von Windows-Anwendungen ohne eine Kopie von Microsoft Windows</de>
   <el>Εκτέλεση εφαρμογών των Windows</el>
   <en>run Windows applications without a copy of Microsoft Windows</en>
   <es_ES>ejecute aplicaciones de Windows sin una copia de Microsoft Windows</es_ES>
   <es>ejecute aplicaciones de Windows sin una copia de Microsoft Windows</es>
   <et>run Windows applications without a copy of Microsoft Windows</et>
   <eu>run Windows applications without a copy of Microsoft Windows</eu>
   <fa>run Windows applications without a copy of Microsoft Windows</fa>
   <fil_PH>run Windows applications without a copy of Microsoft Windows</fil_PH>
   <fi>aja Windows-sovelluksia ilman Microsoft Windowsia</fi>
   <fr_BE>Lancer des applications Windows sans avoir besoin d'installer Windows</fr_BE>
   <fr>Lancer des applications Windows sans avoir besoin d'installer Windows</fr>
   <gl_ES>Executar aplicativos para Windows sen precisar do Microsoft Windows</gl_ES>
   <gu>run Windows applications without a copy of Microsoft Windows</gu>
   <he_IL>run Windows applications without a copy of Microsoft Windows</he_IL>
   <hi>माइक्रोसॉफ्ट विंडोज के बिना ही विंडोज अनुप्रयोग निष्पादित करें</hi>
   <hr>run Windows applications without a copy of Microsoft Windows</hr>
   <hu>run Windows applications without a copy of Microsoft Windows</hu>
   <id>run Windows applications without a copy of Microsoft Windows</id>
   <is>run Windows applications without a copy of Microsoft Windows</is>
   <it>esegue applicazioni Windows senza la presenza del sistema operativo Microsoft Windows</it>
   <ja>Windows のコピーなしで Windows アプリケーションを実行します</ja>
   <kk>run Windows applications without a copy of Microsoft Windows</kk>
   <ko>run Windows applications without a copy of Microsoft Windows</ko>
   <lt>run Windows applications without a copy of Microsoft Windows</lt>
   <mk>run Windows applications without a copy of Microsoft Windows</mk>
   <mr>run Windows applications without a copy of Microsoft Windows</mr>
   <nb_NO>run Windows applications without a copy of Microsoft Windows</nb_NO>
   <nb>kjør Windows-programmer uten å ha Microsoft Windows installert</nb>
   <nl_BE>run Windows applications without a copy of Microsoft Windows</nl_BE>
   <nl>Windowstoepassingen uitvoeren zonder een exemplaar van Microsoft Windows</nl>
   <pl>uruchamiaj aplikacje Windows bez kopii systemu Microsoft Windows</pl>
   <pt_BR>Executa aplicativos para Windows sem precisar de uma cópia do Microsoft Windows</pt_BR>
   <pt>Executar aplicações para Windows sem precisar do Microsoft Windows</pt>
   <ro>run Windows applications without a copy of Microsoft Windows</ro>
   <ru>Запуск приложений для Windows в окружении GNU/Linux</ru>
   <sk>run Windows applications without a copy of Microsoft Windows</sk>
   <sl>Poženite Windows aplikacije brez kopije Microsoft Windows</sl>
   <sq>Xhironi aplikacione Windows pa një kopje të Microsoft Windows-it</sq>
   <sr>run Windows applications without a copy of Microsoft Windows</sr>
   <sv>kör Windows applikationer utan Microsoft Windows</sv>
   <th>รันแอปพลิเคชันจาก Windows โดยไม่ต้องใช้ Microsoft Windows</th>
   <tr>Microsoft Windows'un kopyası olmadan Windows uygulamalarını çalıştırma</tr>
   <uk>run Windows applications without a copy of Microsoft Windows</uk>
   <vi>run Windows applications without a copy of Microsoft Windows</vi>
   <zh_CN>run Windows applications without a copy of Microsoft Windows</zh_CN>
   <zh_HK>run Windows applications without a copy of Microsoft Windows</zh_HK>
   <zh_TW>run Windows applications without a copy of Microsoft Windows</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 276ECD5CEF864D8F
echo "deb http://mxrepo.com/mx/repo/ buster main non-free">/etc/apt/sources.list.d/pitemp1.list
sleep .1
echo "deb http://mxrepo.com/mx/testrepo/ buster test ">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t mx winehq-staging
</install_package_names>


<postinstall>
/usr/share/packageinstaller-pkglist/run_winecfg.sh
rm /etc/apt/sources.list.d/pitemp.list
rm /etc/apt/sources.list.d/pitemp1.list
apt-get update
</postinstall>


<uninstall_package_names>
winehq-staging
</uninstall_package_names>
</app>
